# CPI matplotlib plotting style

This library provides a custom plotting style for [matplotlib][mpl] and
other libraries building on matplotlib like [pandas][pd] or [seaborn][sns].

The plotting style is set to aproximately the styles described in 
[our wiki][wiki], more precicely in this [PowerPoint presentation][ppt].

### Before:

![Default matplotlib style](example_before.png)

### After:

![CPI matplotlib style](example_after.png)

## how to use it

Copy the file `cpi.mplstyle` into the directory with your analysis and tell
matplotlib to use this style:

```python
from matplotlib import pyplot
pyplot.style.use('./cpi.mplstyle')
```

For usage with other graphing libraries like searborn:

```python
from matplotlib import pyplot
import seaborn
pyplot.style.use('./cpi.mplstyle')
```

Be aware that the `set*` functions of seaborn (like set_theme) might mess with the 
matplotlib style. The `seaborn.set_palette()` function to change line colors seems to be woring fine


## set as default style

To use this style as your default matplotlib style, have a look at the 
[matplotlib documentation][default]


## how to make changes

Please add changes only to the file `custom cpi style.txt`. After modifying the file use `python3 compile.py` to generate a file with custom styles.

## the examples

If you are curios on how the examples were created, have a look at the [Jupyter Notebook][jupyter] `example.ipynb`.


[mpl]: https://matplotlib.org/
[pd]: https://pandas.pydata.org/
[sns]: https://seaborn.pydata.org/
[wiki]: https://wiki.cpi.imtek.uni-freiburg.de/ScientificWriting
[ppt]: https://wiki.cpi.imtek.uni-freiburg.de/ScientificWriting?action=AttachFile&do=view&target=140109-scientific-writing-06-figures-and-figure-captions.pptx
[default]: https://matplotlib.org/stable/tutorials/introductory/customizing.html#customizing-with-matplotlibrc-files
[jupyter]: https://jupyter.org/